EMPTY_FTE = '0'


def transform_successfactor_data(bigquery_successfactor):
    data_json = {
        'office_name': 'Madrid - Ing',
        'FTE': 1,
    }

    for data in bigquery_successfactor:
        data_json['office_name'] = data.get('office', '')
        data_json['FTE'] = data.get('fte', 0)

    return data_json


def transform_successfactor_all_data(bigquery_successfactor):
    data_json = {}

    for data in bigquery_successfactor:
        email = data.get('email', '')
        hiringdate = data.get('hiringdate', '')
        enddate = data.get('internshipdate', '')

        if email not in data_json.keys():
            data_json[email] = {}

        fte = data.get('fte', EMPTY_FTE) or EMPTY_FTE  # For null values
        data_json[email]['supervisor'] = data.get('supervisor', '')
        data_json[email]['office_name'] = data.get('office', '')
        data_json[email]['FTE'] = float(fte.replace(',', '.'))
        data_json[email]['hiring_date'] = hiringdate
        data_json[email]['enddate'] = enddate
        data_json[email]['name'] = "{} {}".format(
            data.get('name', ''), data.get('lastname', ''))

    return data_json


def transform_all_capacities(capacities):
    data_json = {}

    for data in capacities:
        email = data.get('email')
        if email not in data_json:
            data_json[email] = {
                'fte': data.get('fte')
            }

    return data_json


def group_task_by_email(month_data, group_by_full_date=False):
    data_by_email = {}
    for task in month_data:
        taskTimeSpent = task.get('timeSpent', 0)
        taskEmail = task.get('authorEmail')
        taskStarted = task.get('started')
        grouped_date = taskStarted.strftime(
            '%Y-%m-%d') if group_by_full_date else taskStarted.day
        if taskEmail not in data_by_email.keys():
            data_by_email[taskEmail] = {'totalHours': 0, 'days': {}}

        if grouped_date not in data_by_email[taskEmail]['days']:
            data_by_email[taskEmail]['days'][grouped_date] = 0

        data_by_email[taskEmail]['totalHours'] += taskTimeSpent
        data_by_email[taskEmail]['days'][grouped_date] += taskTimeSpent

    return data_by_email



from ms_imputedhours_core.employee.data.constants import EXCLUDE_ALERT_EMAILS


def should_exclude_employee(email, date, hired_date, end_date):
    is_email_excluded = email in EXCLUDE_ALERT_EMAILS

    is_personal_email = "@makingscience" not in email

    is_enddate_before_date = end_date and (
        end_date.year, end_date.month) <= (date.year, date.month)

    is_hired_date_after_date = hired_date and (
        hired_date.year, hired_date.month) >= (date.year, date.month)

    return (
        is_email_excluded or
        is_enddate_before_date or
        is_hired_date_after_date or
        is_personal_email)



from setuptools import setup, find_packages
from ms_imputedhours_core import __version__
from pathlib import Path


this_directory = Path(__file__).parent
long_description = (this_directory / 'README.md').read_text()

setup(
    name='ms_imputedhours_core',
    version=__version__,
    packages=find_packages(),
    author='Jonathan Rodriguez Alejos',
    author_email='jrodriguez.5716@gmail.com',
    install_requires=open('requirements.txt').read().splitlines(),
    long_description=long_description,
    long_description_content_type='text/markdown'
)
